function [x,y,maxJ,minJ]=JBtexture(testImage,showfigs,nhsize,strip, ...
    threshval,num_erodes,num_dilates, downstreamStrip, TopStrip, ...
    BottomStrip, XMark, YMark, mask, liqCoreMask, x_c, complement)

% Function calculates the standard deviation across a single image.
% Used when background is irregular and the jet fairly uniform 
% - Timothy C.Williams 1/23/2008

orgn = [YMark x_c];

nColumns = size(testImage,2);
nRows    = size(testImage,1);

% Pixel size of region used for standard deviation
% Comes from "Size of stdev filter in pixels (odd #) control in GUI
% (edtInput1_1 when pumStrategy1 == texture (stdev))
nh=ones(nhsize,nhsize);  

% Local standard deviation of image with "nh" neighborhood size
stdv_image = stdfilt(testImage,nh);

% Zero penetration doesn't work....make XMark = 1
if XMark == 0; 
    XMark=1;
end 

% Normalize image by max value and then apply user supplied threshold
maxlevel=max(max(stdv_image));
stdv_image=stdv_image/maxlevel;

% Normalized threshold level
%    threshval comes from "Threshold Value" on GUI (edtInput1_3)
level = threshval/maxlevel;

% Obtain black and white conversion at given threshold using mask
BW_stdvIm = im2bw(stdv_image,level) & mask;%(im2bw(1-stdv_image,level)) & mask;

% Complement the image using the mask
if complement
    BW_stdvIm = imcomplement(BW_stdvIm) & mask;
end

% Error check the region of interest inputs:
if strip > nColumns
    strip = nColumns;
end
if downstreamStrip > nColumns
    message = {'Exceeded possible value for downstreamStrip.'; ...
              ['Maximum value = ' sprintf('%d pixels',nColumns)]};
    errordlg(message)
    return
end
if TopStrip > nRows
    TopStrip = nRows;
end
if BottomStrip > nRows
    BottomStrip = nRows;
end

% Ignore other regions not of interest (not covered by mask)
BW_stdvIm(:,1:strip)=0;                   % Make strip next to injector 0
BW_stdvIm(:,downstreamStrip:nColumns)=0;  % Make downstream strip 0
BW_stdvIm(1:TopStrip,:)=0;                % Make top strip 0
BW_stdvIm(nRows-BottomStrip:nRows,:)=0;   % Make bottom strip 0

% Labels connected components in image
L = bwlabel(BW_stdvIm,4); % Find the already connected regions within the input image IM 

if isempty(XMark)==0; % Test if a location for the X mark has been supplied
    
    % Was the mark position calculated as being too far out?
    if XMark > nColumns 
        % If so, divide by 2 and hope for the best
        XMark = nColumns/2;
    end
    LabelNum = L(round(YMark),round(XMark)); % If it has then find the region under the mark X
else
    RegionAreas = regionprops(L, 'area'); % If it hasn't then find the largest region
    Area = cat(1, RegionAreas.Area);
    LabelNum=find(Area==max(Area));
end

if isempty(LabelNum)
    x=[];y=[];maxJ=[];minJ=[];
    return
end
if LabelNum == 0
    x=[];y=[];maxJ=[];minJ=[];
    return
end

JET = zeros(size(BW_stdvIm));
JET(L==LabelNum)=1;  %fill JET with just the largest region

JET = imfill(JET,'holes');

% Perform the liquid core mask again in case erode operations removed it.
if liqCoreMask % Another user option - can be turned off
    JET = applyLiqCoreMask(JET,orgn);
end

% % Create a 'disk' structuring element for an imclose operation:
% seDiskRadius = 2;
% seDiskN      = 4;
% seDisk = strel('disk',seDiskRadius,seDiskN);
% BW_Image=imclose(BW_Image,seDisk);


JET = bwmorph(JET,'erode',num_erodes); 
JET = bwmorph(JET,'dilate',num_dilates); 
JET = imfill(JET,'holes');

% Perform the liquid core mask again in case erode operations removed it.
if liqCoreMask && num_erodes > 0
    JET = applyLiqCoreMask(JET,orgn);
end


% erodes can form disconnected regions to form, this part keeps the
% region that's still under the X
L = bwlabel(JET,8); %Find the already connected regions within the input image IM 
RegionAreas = regionprops(L, 'area');
Area = cat(1, RegionAreas.Area);
LabelNum=find(Area==max(Area));
if isempty(LabelNum) == 1; % the region has been eroded to nothing!!!
    x=[];y=[];return;
end; 

if isempty(XMark)==0; % test if a location for the X mark has been surplied
    LabelNum = L(round(YMark),round(XMark)); % if it has then find the region under the mark X
end;

if isempty(LabelNum) == 1 || LabelNum == 0;
    x=[];y=[];return;
end;  

JET = zeros(size(JET));
JET(L==LabelNum)=1;

% find the boundary of the region to send back to the GUI as x,y coordinates
%Also send back max and min
JetBoundary = bwboundaries(JET);
[r,c]=find(JET); 
if ~isempty(c) 
    maxJ=max(c);
    minJ=min(c);
else
    maxJ=0; minJ=100;
end

x = JetBoundary{1}(:,2);
y = JetBoundary{1}(:,1);

if showfigs==1
end


