function [x,y]=JBtextureDIFF(TestImage1, TestImage2,showfigs,nhsize, ...
    strip,thresval,num_erodes,num_dilates, downstreamStrip, TopStrip, ...
    BottomStrip, XMark, YMark, mask, liqCoreMask, x_c, complement)

% Function calculates the standard deviation across a single image.
% Used when background is irregular and the jet fairly uniform - Timothy C.Williams 1/23/2008

orgn = [YMark x_c];

nColumns = size(TestImage1,2);
nRows    = size(TestImage1,1);

% Pixel size of region used for standard deviation
% Comes from "Size of stdev filter in pixels (odd #) control in GUI
% (edtInput1_1 when pumStrategy1 == texture (stdev))
nh=ones(nhsize,nhsize);


TestImage = TestImage1 - TestImage2;
stdv_image = stdfilt(TestImage,nh); % Standard deviation across the image

%figure, imagesc(stdv_image); 

if XMark == 0
    XMark=1;
end % zero penetration doesn't work....make XMark = 1

%normalise image by max value and then apply user supplied threshold %%%%%%
maxlevel=max(max(stdv_image));
stdv_image=stdv_image/maxlevel;
level = thresval/maxlevel;

%BW_stdvIm = imcomplement(im2bw(stdv_image,level));
BW_stdvIm = im2bw(stdv_image,level);
%figure; imagesc(BW_stdvIm); 

% Complement the image using the mask
if complement
    BW_stdvIm = imcomplement(BW_stdvIm) & mask;
end

BW_stdvIm(:,1:strip)=0;  %make strip next ot injector 0
BW_stdvIm(:,downstreamStrip:nColumns)=0;  %make downstream strip 0
BW_stdvIm(1:TopStrip,:)=0;  %make top strip 0
BW_stdvIm(nRows-BottomStrip:nRows,:)=0;   % Make bottom strip 0

L = bwlabel(BW_stdvIm,8); %Find the already connected regions within the input image IM 

if isempty(XMark)==0; % test if a location for the X mark has been surplied
    LabelNum = L(round(YMark),round(XMark)); % if it has then find the region under the mark X
else
    RegionAreas = regionprops(L, 'area'); % if it hasn't then find the largest region
    Area = cat(1, RegionAreas.Area);
    LabelNum=find(Area==max(Area));
end;

if isempty(LabelNum) == 1;
    x=[];y=[];return;
end;  
if LabelNum == 0;
    x=[];y=[];return;
end;

JET = zeros(size(BW_stdvIm));
JET(L==LabelNum)=1;  %fill JET with just the largest region


JET = imfill(JET,'holes');

% Applies a mask designed to block in the unmoving liquid core that often
% does not get included in the jet using the various techniques.
if liqCoreMask
    JET = applyLiqCoreMask(JET,orgn);
end

% % Create a 'disk' structuring element for an imclose operation:
% seDiskRadius = 2;
% seDiskN      = 4;
% seDisk = strel('disk',seDiskRadius,seDiskN);
% BW_Image=imclose(BW_Image,seDisk);

JET = bwmorph(JET,'erode',num_erodes); 
JET = bwmorph(JET,'dilate',num_dilates); 
JET = imfill(JET,'holes');

% Perform the liquid core mask again in case erode operations removed it.
if liqCoreMask && num_erodes > 0
    JET = applyLiqCoreMask(JET,orgn);
end

% erodes can form disconnected regions to form, this part keeps the
% region that's still under the X
L = bwlabel(JET,8); %Find the already connected regions within the input image IM 
RegionAreas = regionprops(L, 'area');
Area = cat(1, RegionAreas.Area);
LabelNum=find(Area==max(Area));
if isempty(LabelNum) == 1; % the region has been eroded to nothing!!!
    x=[];y=[];return;
end; 

if isempty(XMark)==0; % test if a location for the X mark has been surplied
    LabelNum = L(round(YMark),round(XMark)); % if it has then find the region under the mark X
end;

if isempty(LabelNum) == 1 || LabelNum == 0;
    x=[];y=[];return;
end;  

JET = zeros(size(JET));
JET(L==LabelNum)=1;

% find the boundary of the region to send back to the GUI as x,y coordinates
JetBoundary = bwboundaries(JET);
x = JetBoundary{1}(:,2);
y = JetBoundary{1}(:,1);
if showfigs==1
end;


