function [x,y]=JBthreshold(TestImage1,showfigs,complement,strip, ...
    threshval,num_erodes,num_dilates, downstreamStrip, ...
    TopStrip, BottomStrip, XMark, YMark, liqCoreMask, x_c, mask)

orgn = [YMark x_c];
nColumns = size(TestImage1,2);
nRows = size(TestImage1,1);

% Normalize image by max value and then apply user supplied threshold
maxlevel=max(max(TestImage1));
scaledImage = TestImage1/maxlevel;

% Normalized threshold level
%    threshval comes from "Threshold Value" on GUI (edtInput1_3)
%level = threshval/maxlevel;


BW_Image = im2bw(scaledImage,threshval) & mask;

if complement
    BW_Image = imcomplement(BW_Image) & mask; 
end

BW_Image(:,1:strip)=0;
BW_Image(:,downstreamStrip:nColumns)=0;  %make downstream strip 0
BW_Image(1:TopStrip,:)=0;  %make top strip 0
BW_Image(nRows-BottomStrip:nRows,:)=0;  %make bottom strip 0

BW_Image = imfill(BW_Image,'holes');

% Perform the liquid core mask again in case erode operations removed it.
if liqCoreMask % Another user option - can be turned off
    BW_Image = applyLiqCoreMask(BW_Image,orgn);
end

% Create a 'disk' structuring element for an imclose operation:
%seDiskRadius = 2;
%seDiskN      = 4;
%seDisk = strel('disk',seDiskRadius,seDiskN);
%BW_Image=imclose(BW_Image,seDisk);


L = bwlabel(BW_Image,8); %Find the already connected regions within the input image IM 

if ~isempty(XMark) % test if a location for the X mark has been surplied
    try
        % If it has then find the region under the mark X
        LabelNum = L(round(YMark),round(XMark)); 
    catch
        LabelNum = 1;
    end
else
    RegionAreas = regionprops(L, 'area'); % if it hasn't then find the largest region
    Area = cat(1, RegionAreas.Area);
    LabelNum=find(Area==max(Area));
end

if isempty(LabelNum) == 1;
    x=[];y=[];return;
end
if LabelNum == 0;
    x=[];y=[];return;
end

JET = zeros(size(BW_Image));
JET(L==LabelNum)=1;  %fill JET with just the largest region
JET = imfill(JET,'holes');
JET = bwmorph(JET,'erode',num_erodes); 
JET = bwmorph(JET,'dilate',num_dilates); 
JET = imfill(JET,'holes');

% Perform the liquid core mask again in case erode operations removed it.
if liqCoreMask && num_erodes > 0
    JET = applyLiqCoreMask(JET,orgn);
end

% erodes can form disconnected regions to form, this part keeps the
% region that's still under the X
L = bwlabel(JET,8); %Find the already connected regions within the input image IM 
RegionAreas = regionprops(L, 'area');
Area = cat(1, RegionAreas.Area);
LabelNum=find(Area==max(Area));
if isempty(LabelNum) == 1; % the region has been eroded to nothing!!!
    x=[];y=[];return;
end; 

if isempty(XMark)==0; % test if a location for the X mark has been surplied
    try
        % If it has then find the region under the mark X
        LabelNum = L(round(YMark),round(XMark)); 
    catch
        LabelNum = 1;
    end
end

if isempty(LabelNum) == 1 || LabelNum == 0;
    x=[];y=[];return;
end

JET = zeros(size(JET));
JET(L==LabelNum)=1;

% find the boundary of the region to send back to the GUI as x,y coordinates
JetBoundary = bwboundaries(JET);
x = JetBoundary{1}(:,2);
y = JetBoundary{1}(:,1);
if showfigs==1
end







