function JET = applyLiqCoreMask(JET, orgn)
% Applies a mask designed to block in the unmoving liquid core that often
% does not get included in the jet using the various techniques.
%
% INPUTS:
% JET - binary image of spray jet
% orgn(1) - y position of the jet origin
% orgn(2) - x position of the jet origin
% 
% OUTPUTS: 
% Modified JET boundary with liqCoreMask

nColumns = size(JET,2);
nRows    = size(JET,1);
[b]=jetBoundary(JET);
[S,indxmax]=max(b(:,2));                                                   %#ok<NASGU>
[y1,indy1]=min(b(:,1)); a= b(:,1)==y1; indx1=min(b(a,2));                  %#ok<NASGU>
[y2,indy2]=max(b(:,1)); a= b(:,1)==y2; indx2=min(b(a,2));                  %#ok<NASGU>
yblock=max([orgn(1)-y1 y2-orgn(1)])/3; 
xblock=min([indx1 indx2]);
xpoly=[orgn(2)+2 xblock mean([xblock S]) S*.8 mean([xblock S]) xblock];  % That 0.8 decreases the polygon penetration
ypoly=orgn(1)+[0 -yblock -yblock/1.3 0 yblock/1.3 yblock];
BWmask=roipoly(nRows,nColumns,xpoly,ypoly);

% A jet-shaped neighborhood for dilation procedure
nhood = [0 0 0 0 0 0 0 0 0 0; ...
         0 0 0 0 0 1 1 1 0 0; ...
         0 0 0 0 1 1 1 1 1 1; ...
         1 1 1 1 1 1 1 1 1 1; ...
         0 0 0 0 1 1 1 1 1 1; ...
         0 0 0 0 0 1 1 1 0 0; ...
         0 0 0 0 0 0 0 0 0 0];
se = strel('arbitrary',nhood);

% Perform two dilate operations 
%BWmask = imdilate(BWmask,se);
BWmask = imdilate(BWmask,se);

% Adds liquid core to jet boundary JET
JET=JET|BWmask; 