function [images] = ifpImageConvert(fileprefix,imgNums)


% --- INPUTS ---
% 
% fileprefix is the full path plus the prefix of the images (the part
%   before the number indices). Example:
%   'C:\xdata\Schlieren_DarkField\NonReacting\Essai_00\images\images'
%   where the last images is the first part of a filename such as
%   images000001.tif.
%
% imgNums is an optional argument to specify which images to use for the
%   analysis (ex: 10:100 starts at image 10 and goes to 100). If not
%   specified, all images will be used.

% --- OUPTUT ---
%
% images is an m by n by i array of images. All other relevant data is
% saved to an images.mat file for use in the GUI.

% Origin and scale data:
xOrigin = 640-626;
yOrigin = 203;
scale   = 50/(572-164);

% Experimental Parameters (see dcsfFileExtract for syntax to fill this in)
O2 = ' ';
Temp = ' ';
Density = ' ';
InjPress = ' ';
Orifice = ' ';

% Timing (time of first frame relative to start of injection, seconds)
tASOI = -296e-6;


disp('Check origin and scale!')
fprintf('X Origin: %d\n',xOrigin)
fprintf('Y Origin: %d\n',yOrigin)
fprintf('Scale: %g pixels/mm \n\n',scale)



% Strips just the directory from the fileprefix
bSlashes = regexp(fileprefix,'\');
path = fileprefix(1:bSlashes(end));
currDir = cd;
cd(path)

% Open the *.cih file to pull any relevant data from there
fid = fopen('images.cih');
dum = textscan(fid,'%s',11,'delimiter','\n'); % Irrelevant
frameRate16 = textscan(fid,'%s %s %s %d',1,'delimiter',' '); frameRate16 = double(frameRate16{4});
dum = textscan(fid,'%s',4,'delimiter','\n'); % Irrelevant
imageCount = textscan(fid,'%s %s %s %d',1,'delimiter',' '); imageCount = imageCount{4};
firstImageNumber = textscan(fid,'%s %s %s %d',1,'delimiter',' '); firstImageNumber = firstImageNumber{4};
dum = textscan(fid,'%s',3,'delimiter','\n'); % Irrelevant
w = textscan(fid,'%s %s %s %d',1,'delimiter',' '); w = w{4};
h = textscan(fid,'%s %s %s %d',1,'delimiter',' '); h = h{4};
status = fclose(fid);

% Image size
imSize(1) = w;
imSize(2) = h;

% Time array (one for each frame, microseconds)
ts = 1/double(frameRate16);
t1 = zeros(imageCount,1);
t1(1) = tASOI;
for i=2:imageCount
    t1(i) = t1(i-1) + ts;
end

if nargin < 2
    imgNums = firstImageNumber+1:imageCount;
else
    firstImageNumber = imgNums(1);
    imageCount = length(imgNums);
end

% Imports the raw image data into a matlab binary variable.
for i = imgNums
    filename = sprintf('%s%.6d.tif',fileprefix,i);
    [images(:,:,i),message]=imread(filename);
    images(:,:,i) = imflip(images(:,:,i));
end

save images.mat images frameRate16 imageCount firstImageNumber ...
     O2 Temp Density InjPress Orifice imSize t1

% Go back to the calling directory after finished
cd(currDir)