%[S, mdot, U] = jetPen(d,rhoa,rhof,DP,t,sa)
%d (mm),rhoa (kg/m3), rhof (kg/m3), DP (MPa), t (ms), sa=tan(q/2)
%S (mm), mdot returned in kg/s, velocity in m/sec.


function S = jetPenCalculation(d,rhoa,rhof,DP,t,sa)

   % Convert orifice diameter from millimeters to meters
   d = d/1000; 
   
   % Estimate of discharge coefficient 
   Cd = 0.80;
   
   % Estimate of area contraction coefficient
   Ca = 0.86;  
   
   % Estimate of ???
   a = 0.255;
   
   % Convert time to seconds
   t = t/1000; 
   t(t<0)=0; % Negative time means zero penetration, t=0
   
   % Effective nozzle diameter (reduced by Ca)
   df =d * Ca^0.5;
   
   % rhotilde is the fuel density / air density
   rhotilde = rhof/rhoa;
   
   
   if nargin<6
        sa=a*((1/rhotilde)^0.19-0.0043*(sqrt(rhotilde))); % in tan(theta/2)
   end
   
   
   xplus = df*sqrt(rhotilde)/(0.75*sa);
   U =Cd/Ca*sqrt(2*DP.*1000000/rhof);
   tplus = xplus/1000./U;
   ttilde = t ./ tplus;
   stilde = ttilde./(1+ttilde.^(2.2/2)).^(1/2.2);
   S = stilde .* xplus;
  
   
return


 
