function [theta_l,maxV,time] = thetabymm(jbmmfilename,varargin)
%THETABYPIX uses the saved jet boundary to find the spray angle by
%millimeter region from the injector until the jet penetration
%   Use:
%   theta_l = THETABYPIX(jbmmfilename,[scale])
%       Where:
%       jbmmfilename is the jet boundary millimeter file that contains the 
%       jet boundary per frame
%       theta_l is the returned spray angle by millimeter region per frame
%
%       If you want all the theta_l's plotted on the same graph as well,
%       supply a second input, scale, which can be anything.
%
%   Last modified:
%   Nathan Greco - 2/26/2010

    [pathstr,name,ext,ver] = fileparts(jbmmfilename); 
    jbmmfilename = fullfile(pathstr,[name '.jb_mm']); %if no extension passed in, that's okay
    S = load(jbmmfilename,'-mat'); %JBmm
    [row, col] = find(cellfun(@(x)~isempty(x),S.JB_mm),1,'first'); %find first non-empty row
    %S.JB_mm = S.JB_mm(row:end,:); %Get rid of empty frame information from beginning
    theta_l = cell(length(S.JB_mm(:,1)),1); %preallocate some of the array
    maxV = zeros(length(S.JB_mm(:,1)),1);
    time = S.timeV(1:length(S.JB_mm(:,1)));
    %msgbox('This may take a few seconds...')
    for j = row:length(S.JB_mm(:,1)) %by frame
        maxV(j) = max(S.JB_mm{j,2});
        SPix = (max(S.JB_mm{j,2} + 500) - min(S.JB_mm{j,2} + 500))-500;
        w = zeros(1,SPix); %preallocate w for each frame
        for k=1:floor(length(S.JB_mm{j,1})/2) %by millimeter region.
            %Note: S.JB_mm{j,1}/2 gives you approximately the number of millimeter
            %regions to measure angles for
            mx = S.JB_mm{j,1}(end+1-k); %max value
            mn = S.JB_mm{j,1}(k); %min value
            w(k) = mx - mn; %height of millimeter region
            theta_l{j}(k) = 2*atand(w(k)/(2*k)); %angle
        end %by millimeter region
    end %by frame
    if nargin > 1
        hold all 
        cellfun(@(x)plot(x),theta_l(50:end)) %plots all frame angles on one axes
    end
end %function

